@@ -55,8 +55,8 @@ class Transfer(Transaction):
             raise Exception('Incorrect Version')
 
     def to_json(self):
-        return (crypto.merge_dicts({
-            "id": self.id if self.id else "",
+        return crypto.clean_dict({
+            "id": self.id,
             "type": self.TYPE,
             "version": self.version,
             "sender": self.sender,
@@ -67,9 +67,12 @@ class Transfer(Transaction):
             "amount": self.amount,
             "recipient": self.recipient,
             "attachment": base58.b58encode(crypto.str2bytes(self.attachment)),
-            "proofs": self.proofs,
-            "height": self.height if self.height else ""
-        }, self._sponsor_json()))
+            "sponsor": self.sponsor,
+            "sponsorKeyType": self.sponsor_key_type,
+            "sponsorPublicKey": self.sponsor_public_key,
+            "proofs": self.proofs or None,
+            "height": self.height
+        })
 
     @staticmethod
     def from_data(data):
